==> mlcp-9.0.5-sources.jar: com/marklogic/contentpump/DatabaseContentOutputFormat.java <==
/*
 * Copyright 2003-2018 MarkLogic Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.marklogic.contentpump;

import java.io.IOException;
import java.util.Map;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.mapreduce.RecordWriter;
import org.apache.hadoop.mapreduce.TaskAttemptContext;

import com.marklogic.mapreduce.ContentOutputFormat;
import com.marklogic.mapreduce.DocumentURI;
import com.marklogic.xcc.ContentSource;

/**
 * ContentOutputFormat for importing archive to MarkLogic and copying from
 * source MarkLogic Server to destination MarkLogic Server.
 * 
 * @author ali
 * 
 */
public class DatabaseContentOutputFormat extends
    ContentOutputFormat<DatabaseDocumentWithMeta> {
    @Override
    public RecordWriter<DocumentURI, DatabaseDocumentWithMeta> getRecordWriter(
        TaskAttemptContext context) throws IOException, InterruptedException {
        Configuration conf = context.getConfiguration();
        fastLoad = Boolean.valueOf(conf.get(OUTPUT_FAST_LOAD));
        Map<String, ContentSource> sourceMap = getSourceMap(fastLoad, context);
        // construct the DatabaseContentWriter
        return new DatabaseContentWriter<DatabaseDocumentWithMeta>(conf,
            sourceMap, fastLoad, am);
    }
}

==> mlcp-11.3.1-sources.jar: com/marklogic/contentpump/DatabaseContentOutputFormat.java <==
/*
 * Copyright (c) 2021 MarkLogic Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.marklogic.contentpump;

import java.io.IOException;
import java.util.Map;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.mapreduce.RecordWriter;
import org.apache.hadoop.mapreduce.TaskAttemptContext;

import com.marklogic.mapreduce.ContentOutputFormat;
import com.marklogic.mapreduce.DocumentURI;
import com.marklogic.xcc.ContentSource;

/**
 * ContentOutputFormat for importing archive to MarkLogic and copying from
 * source MarkLogic Server to destination MarkLogic Server.
 * 
 * @author ali
 * 
 */
public class DatabaseContentOutputFormat extends
    ContentOutputFormat<DatabaseDocumentWithMeta> {
    @Override
    public RecordWriter<DocumentURI, DatabaseDocumentWithMeta> getRecordWriter(
        TaskAttemptContext context) throws IOException, InterruptedException {
        Configuration conf = context.getConfiguration();
        fastLoad = Boolean.valueOf(conf.get(OUTPUT_FAST_LOAD));
        Map<String, ContentSource> sourceMap = getSourceMap(fastLoad, context);
        // construct the DatabaseContentWriter
        return new DatabaseContentWriter<>(conf,
            sourceMap, fastLoad, am);
    }
}
